@@ -9,7 +9,7 @@ BEGIN {
 use strict;
 use warnings;
 
-our $VERSION = '0.1910';
+our $VERSION = '0.1911';
 
 1;
 
@@ -25,7 +25,7 @@ Task::MusicBundle - MIDI and music creation modules
 
 =head1 VERSION
 
-version 0.1910
+version 0.1911
 
 =head1 SYNOPSIS
 
@@ -98,6 +98,10 @@ L<Music::Chord::Positions>
 
 L<Music::Chord::Progression>
 
+L<Music::Chord::Progression::Transform>
+
+L<Music::CreatingRhythms>
+
 L<Music::Duration>
 
 L<Music::Duration::Partition>
@@ -152,7 +156,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by Gene Boggs.
+This software is copyright (c) 2013-2023 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
